Bank Recurring Investigation

This python package investigates Banking data using Pansdas and Pyspark. It is written as a part of an MHPC master project in a joint program of ICTP/SISSA and Prometeia company.



	
	
